// ****************************************************************** 
//       * Functions triggered by events in client user interface
// ******************************************************************

// ************************************************************************************
// Name   : client_SetExternalFrequency()
// Purpose: Called when user selects a external frequency value.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : anEvent
// Outputs: NONE
function client_SetExternalFrequency(anEvent)
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : 
                  ((anEvent.which) ? anEvent.which : anEvent.keyCode);
   if (charCode == 13 || charCode == 3)
   {
      var anElement = Get_Iframe_Element( 'ExternalFrequencyInput' ) ;
      if ( anElement )
      {
         if (IsNumber(anElement))
         {
            if (IsChangeConfirmed("External Frequency"))
            {
               var aFrequency = parseInt((parseFloat(anElement.value)) * 1000000, 10);
               serverIntfGeneralIntf.SetExternalFrequency(aFrequency);
               anElement.value = FormatNumber((aFrequency / 1000000), 6);;
               Focus_Iframe();
            }
         }
      }
   }                          
};

// ************************************************************************************
// Name   : client_SetReferenceFrequencySource()
// Purpose: Called when user selects a reference frequency source interface.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetReferenceFrequencySource()
{
   var anElement = Get_Iframe_Element( 'ReferenceFrequencySourceSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Reference Frequency Source"))
      {
         serverIntfGeneralIntf.SetReferenceFrequencySource(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetReferenceFrequency()
// Purpose: Called when user selects a external frequency value.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : anEvent
// Outputs: NONE
function client_SetReferenceFrequency(anEvent)
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : 
                  ((anEvent.which) ? anEvent.which : anEvent.keyCode);
   if (charCode == 13 || charCode == 3)
   {
      var anElement = Get_Iframe_Element( 'ReferenceFrequencyInput' ) ;
      if ( anElement )
      {
         if (IsNumber(anElement))
         {
            if (IsChangeConfirmed("Reference Frequency"))
            {
               var aFrequency = parseInt((parseFloat(anElement.value)) * 1000000);
               serverIntfGeneralIntf.SetReferenceFrequency(aFrequency);
               anElement.value = FormatNumber((aFrequency / 1000000), 6);;
               Focus_Iframe();
            }
         }
      }
   }
};


// ************************************************************************************
// Name   : client_SetRxIntfSetupStatusUpdate()
// Purpose: Called when the current iFrame loads
// Inputs : NONE
// Outputs: NONE
function client_SetIntfGeneralStatusUpdate()
{
   serverIntfGeneralIntf.SetIntfGeneralSelectContentUpdate();
   serverIntfGeneralIntf.SetIntfGeneralStatusUpdate();
};


// ****************************************************************** 
// * Functions called asynchronously from the server.
// ******************************************************************

function asyncUpdateIntfExternalFrequencyStatus(anExternalFrequency)
{
   var anElement = Get_Iframe_Element( 'ExternalFrequencyInput' ) ;
   if ( anElement )          // Set external frequency
      anElement.value = FormatNumber((anExternalFrequency / 1000000), 6);;
}

function asyncUpdateIntfReferenceFrequencySourceStatus(aReferenceFrequencySource)
{
   var anElement = Get_Iframe_Element( 'ReferenceFrequencySourceSelect' ) ;
   if ( anElement )            // Set reference frequency source
      anElement.value = aReferenceFrequencySource;
}

function asyncUpdateIntfReferenceFrequencyStatus(aReferenceFrequency)
{
   var anElement = Get_Iframe_Element( 'ReferenceFrequencyInput' ) ;
   if ( anElement )               // Set reference frequency
      anElement.value = FormatNumber((aReferenceFrequency / 1000000), 6);;
}

// ****************************************************************** 
// * Functions to update the select content.
// ******************************************************************

function asyncUpdateIntfReferenceFrequencySourceSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'ReferenceFrequencySourceSelect', aSelectContent );
}

