// ****************************************************************** 
//       * Functions triggered by events in client user interface
// ******************************************************************

// ************************************************************************************
// Name   : client_SetRxDataRate()
// Purpose: Called when user selects a receive data rate from the RxDataRate edit box.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : anEvent
// Outputs: NONE
function client_SetRxDataRate(anEvent)
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : 
                  ((anEvent.which) ? anEvent.which : anEvent.keyCode);
   if (charCode == 13 || charCode == 3)
   {
      var anElement = Get_Iframe_Element( 'RxDataRateInput' ) ;
      if ( anElement )
      {
         if (IsNumber(anElement))
         {
            if (IsChangeConfirmed("Rx Data Rate"))
            {
               serverRcvDataIntf.SetRxDataRate(parseInt(anElement.value, 10));
               Focus_Iframe();
            }
         }
      }                                    
   }
};

// ************************************************************************************
// Name   : client_SetRxEscOverhead()
// Purpose: Called when user selects a receive ESC overhead from the RxEscOverhead edit box.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxEscOverhead()
{
   var anElement = Get_Iframe_Element( 'RxEscOverheadSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx ESC Overhead"))
      {
         serverRcvDataIntf.SetRxEscOverhead(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetRxInnerFec()
// Purpose: Called when user selects a receive Inner Fec from the RxInnerFec combo box.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxInnerFec()
{
   var anElement = Get_Iframe_Element( 'RxInnerFecSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx Inner FEC"))
      {
         serverRcvDataIntf.SetRxInnerFec(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
   setTimeout("RefreshIframe();", 250);
};

// ************************************************************************************
// Name   : client_SetRxTPCInterleaver()
// Purpose: Called when user selects a receive TPC Interleaver.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxTPCInterleaver()
{
   var anElement = Get_Iframe_Element( 'RxTPCInterleaverSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx TPC Interleaver"))
      {
         serverRcvDataIntf.SetRxTPCInterleaver(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
function client_SetRxSatelliteFramingCat()
{
   var anElement = Get_Iframe_Element( 'RxSatelliteFramingCatSelect' ) ;
   if( anElement )
   {
      if( IsChangeConfirmed( "Rx Satellite Framing" ) )
      {
         serverRcvDataIntf.SetRxSatelliteFramingCat( parseInt( anElement.value ), 10 );
         Focus_Iframe();
      }
   }
   setTimeout( "RefreshIframe();", 250 );
};

// ************************************************************************************
// Name   : client_SetRxTerrestrialFraming()
// Purpose: Called when user selects a receive terrestrial framing.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxTerrestrialFraming()
{
   var anElement = Get_Iframe_Element( 'RxTerrestrialFramingSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx Terrestrial Framing"))
      {
         serverRcvDataIntf.SetRxTerrestrialFraming(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetRxScramblerControl()
// Purpose: Called when user selects a receive scrambler control from the RxScramblerControl combo box.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxScramblerControl()
{
   var anElement = Get_Iframe_Element( 'RxScramblerControlSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx Scrambler Control"))
      {
         serverRcvDataIntf.SetRxScramblerControl(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetRxScramblerSelection()
// Purpose: Called when user selects a receive scrambler selection from the RxScramblerSelection combo box.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxScramblerSelection()
{
   var anElement = Get_Iframe_Element( 'RxScramblerSelectionSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx Scrambler Selection"))
      {
         serverRcvDataIntf.SetRxScramblerSelection(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetRxDifferentialCoding()
// Purpose: Called when user selects a receive differetial coding.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxDifferentialCoding()
{
   var anElement = Get_Iframe_Element( 'RxDifferentialCodingSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx Differetial Coding"))
      {
         serverRcvDataIntf.SetRxDifferentialCoding(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetRxDataPolarity()
// Purpose: Called when user selects a receive data polarity.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxDataPolarity()
{
   var anElement = Get_Iframe_Element( 'RxDataPolaritySelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx Data Polarity"))
      {
         serverRcvDataIntf.SetRxDataPolarity(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetRxSymbolPair()
// Purpose: Called when user selects a receive Symbol Pair.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxSymbolPair()
{
   var anElement = Get_Iframe_Element( 'RxSymbolPairSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx Symbol Pair"))
      {
         serverRcvDataIntf.SetRxSymbolPair(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetRxSccControlRatio()
// Purpose: Called when user selects a receive Scc Control Ratio.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetRxSccControlRatio()
{
   var anElement = Get_Iframe_Element( 'RxSccControlRatioSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx SCC Control Ratio"))
      {
         serverRcvDataIntf.SetRxSccControlRatio(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetRxSccInbandRate()
// Purpose: Called when user selects a receive data rate from the RxSccInbandRate edit box.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : anEvent
// Outputs: NONE
function client_SetRxSccInbandRate(anEvent)
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : 
                  ((anEvent.which) ? anEvent.which : anEvent.keyCode);
   if (charCode == 13 || charCode == 3)
   {
      var anElement = Get_Iframe_Element( 'RxSccInbandRateInput' ) ;
      if ( anElement )
	   {
		   if (IsNumber(anElement))
		   {
            if (IsChangeConfirmed("Rx SCC Inband Rate"))
            {
               serverRcvDataIntf.SetRxSccInbandRate(parseInt(anElement.value, 10));
               Focus_Iframe();
            }
		   }
	   }
   }
};

// ************************************************************************************
// Name   : client_SetRxAsyncInbandRate()
// Purpose: Called when user selects a transmit data rate from the RxAsyncInbandRateInput
//          combo box.
// Inputs : anEvent
// Outputs: NONE
function client_SetRxAsyncInbandRate()
{
   var anElement = Get_Iframe_Element( 'RxAsyncInbandRateSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Rx Async Inband Rate"))
      {
         serverRcvDataIntf.SetRxAsyncInbandRate(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetRxDataStatusUpdate()
// Purpose: Called when the current iFrame loads
// Inputs : NONE
// Outputs: NONE
function client_SetRxDataStatusUpdate()
{
   serverRcvDataIntf.SetRxDataSelectContentUpdate();
   serverRcvDataIntf.SetRxDataStatusUpdate();
};


// ****************************************************************** 
// * Functions called asynchronously from the server.
// ******************************************************************

function asyncUpdateRcvDataRateStatus(aDataRate)
{
   var anElement = Get_Iframe_Element( 'RxDataRateInput' ) ;
   if ( anElement )
      anElement.value = aDataRate;
}

function asyncUpdateRcvSymbolRateStatus(aSymbolRate)
{
   var anElement = Get_Iframe_Element( 'RxSymbolRateInput' ) ;
   if ( anElement )
      anElement.value = aSymbolRate;
}

function asyncUpdateRcvEscOverheadStatus(anEscOverhead)
{
   var anElement = Get_Iframe_Element( 'RxEscOverheadSelect' ) ;
   if ( anElement )
      anElement.value = anEscOverhead;
}

function asyncUpdateRcvInnerFecStatus(anInnerFec)
{
   var anElement = Get_Iframe_Element( 'RxInnerFecSelect' ) ;
   if ( anElement )
      anElement.value = anInnerFec;
}

function asyncUpdateRcvTPCInterleaverStatus(aTPCInterleaver)
{
   var anElement = Get_Iframe_Element( 'RxTPCInterleaverSelect' ) ;
   if ( anElement )
      anElement.value = aTPCInterleaver;
}

function asyncUpdateRcvSatelliteFramingCatStatus( aSatelliteFramingCat )
{
   var anElement = Get_Iframe_Element( 'RxSatelliteFramingCatSelect' ) ;
   if( anElement )
      anElement.value = aSatelliteFramingCat;
}

function asyncUpdateRcvTerrestrialFramingStatus(aTerrestrialFraming)
{
   var anElement = Get_Iframe_Element( 'RxTerrestrialFramingSelect' ) ;
   if ( anElement )
      anElement.value = aTerrestrialFraming;
}

function asyncUpdateRcvScramblerControlStatus(aScramblerControl)
{
   var anElement = Get_Iframe_Element( 'RxScramblerControlSelect' ) ;
   if ( anElement )		      // Set receive scrambler control
      anElement.value = aScramblerControl;
}

function asyncUpdateRcvScramblerSelectionStatus(aScramblerSelection)
{
   var anElement = Get_Iframe_Element( 'RxScramblerSelectionSelect' ) ;
   if ( anElement )		      // Set receive scrambler selection
      anElement.value = aScramblerSelection;
}

function asyncUpdateRcvDifferentialCodingStatus(aDifferentialCoding)
{
   var anElement = Get_Iframe_Element( 'RxDifferentialCodingSelect' ) ;
   if ( anElement )		           // Set receive differential coding
      anElement.value = aDifferentialCoding;
}

function asyncUpdateRcvDataPolarityStatus(aDataPolarity)
{
   var anElement = Get_Iframe_Element( 'RxDataPolaritySelect' ) ;
   if ( anElement )		         // Set receive data polarity
      anElement.value = aDataPolarity;
}

function asyncUpdateRcvSymbolPairStatus(aSymbolPair)
{
   var anElement = Get_Iframe_Element( 'RxSymbolPairSelect' ) ;
   if ( anElement )		         // Set receive symbol pair
      anElement.value = aSymbolPair;
}

function asyncUpdateRcvSccControlRatioStatus(aSccControlRatio)
{
   var anElement = Get_Iframe_Element( 'RxSccControlRatioSelect' ) ;
   if ( anElement )	               // Set receive Scc Control Ratio
      anElement.value = aSccControlRatio;
}

function asyncUpdateRcvSccInbandRateStatus(aSccInbandRate)
{
   var anElement = Get_Iframe_Element( 'RxSccInbandRateInput' ) ;
   if ( anElement )
      anElement.value = aSccInbandRate;
}

function asyncUpdateRcvAsyncInbandRateStatus(anAsyncInbandRate)
{
   var anElement = Get_Iframe_Element( 'RxAsyncInbandRateSelect' ) ;
   if ( anElement )	               // Set receive async inband rate
      anElement.value = anAsyncInbandRate;
}

// ****************************************************************** 
// * Functions to update the select content.
// ******************************************************************

function asyncUpdateRcvEscOverheadSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxEscOverheadSelect', aSelectContent );
}

function asyncUpdateRcvInnerFecSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxInnerFecSelect', aSelectContent );
}

function asyncUpdateRcvTPCInterleaverSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxTPCInterleaverSelect', aSelectContent );
}

function asyncUpdateRcvSatelliteFramingCatSelectContent( aSelectContent )
{
   Update_Iframe_Element_Select_Content( 'RxSatelliteFramingCatSelect', aSelectContent );
}

function asyncUpdateRcvTerrestrialFramingSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxTerrestrialFramingSelect', aSelectContent );
}

function asyncUpdateRcvScramblerControlSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxScramblerControlSelect', aSelectContent );
}

function asyncUpdateRcvScramblerSelectionSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxScramblerSelectionSelect', aSelectContent );
}

function asyncUpdateRcvDifferentialCodingSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxDifferentialCodingSelect', aSelectContent );
}

function asyncUpdateRcvDataPolaritySelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxDataPolaritySelect', aSelectContent );
}

function asyncUpdateRcvSymbolPairSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxSymbolPairSelect', aSelectContent );
}

function asyncUpdateRcvSccControlRatioSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxSccControlRatioSelect', aSelectContent );
}

function asyncUpdateRcvAsyncInbandRateSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'RxAsyncInbandRateSelect', aSelectContent );
}
